0.2.21 (unreleased)
=======================

0.2.20 (2019-11-27)
=======================
Finish the User Manual.

0.2.19 (2019-11-27)
=======================

New Features
------------
- Add two example tutorial notebooks.
- Introduce several helper/utitlity functions, e.g. to create your own TLEs
  from orbital parameters.

Bugfixes
~~~~~~~~~~
- Include tests in (installed) package, such that test runner can find them.
- Fix github pages rendering, where css/js wasn't found in static directories
  with a leading underscore (an empty .nojekyll is necessary!)

0.2.18 (2019-11-24)
=======================

Bugfixes
~~~~~~~~~~
- Really show README on PyPI.

0.2.17 (2019-11-24)
=======================

Bugfixes
~~~~~~~~~~
- Show README on PyPI.
- Twine upload didn't work for Python3.5.

0.2.16 (2019-11-24)
=======================
Add wheels for MacOS and Windows.


0.2.0 (2019-11-21)
=======================
Initial release
